@@ -35,94 +35,76 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 
-$cgextensions = cms_join_path($gCms->config['root_path'],'modules',
-			      'CGExtensions','CGExtensions.module.php');
-if( !is_readable( $cgextensions ) )
-{
-  echo '<h1><font color="red">ERROR: The CGExtensions module could not be found.</font></h1>';
-  return;
-}
-require_once($cgextensions);
-
-
 class CGSmartImage extends CGExtensions
 {
   public function __construct()
   {
     parent::__construct();
+    $this->RegisterModulePlugin();
   }
 
-  public function SetParameters()
+  public function InitializeFrontend()
   {
     parent::SetParameters();
 
     // operational params (what to do, with what...)
-    $this->CreateParameter('alias','',$this->Lang('param_alias'));
 
     $this->SetParameterType('noautoscale',CLEAN_INT);
-    $this->CreateParameter('noautoscale','',$this->Lang('param_noautoscale'));
-
     $this->SetParameterType('nobcache',CLEAN_INT);
-    $this->CreateParameter('nobcache','',$this->Lang('param_nobcache'));
-
     $this->SetParameterType('noembed',CLEAN_INT);
-    $this->CreateParameter('noembed','',$this->Lang('param_noembed'));
-
+    $this->SetParameterType('noembed',CLEAN_INT);
     $this->SetParameterType('noauto',CLEAN_INT);
-    $this->CreateParameter('noauto','',$this->Lang('param_noauto'));
-
     $this->SetParameterType('norotate',CLEAN_INT);
-    $this->CreateParameter('norotate','',$this->Lang('param_norotate'));
-
     $this->SetParameterType('notag',CLEAN_INT);
-    $this->CreateParameter('notag','',$this->Lang('param_notag'));
-
     $this->SetParameterType('noremote',CLEAN_INT);
-    $this->CreateParameter('noremote','',$this->Lang('param_noremote'));
-
     $this->SetParameterType('src',CLEAN_STRING);
-    $this->CreateParameter('src','',$this->Lang('param_src'),false);
-
     $this->SetParameterType('overwrite',CLEAN_INT);
-    $this->CreateParameter('overwrite','',$this->Lang('param_overwrite'));
 
     // params for the output tag (if outputting an img tag)
     $this->SetParameterType('id',CLEAN_STRING);
-    $this->CreateParameter('id','',$this->Lang('param_id'));
-
     $this->SetParameterType('class',CLEAN_STRING);
-    $this->CreateParameter('class','',$this->Lang('param_class'));
-
     $this->SetParameterType('style',CLEAN_STRING);
-    $this->CreateParameter('style','',$this->Lang('param_style'));
-
     $this->SetParameterType('title',CLEAN_STRING);
-    $this->CreateParameter('title','',$this->Lang('param_title'));
-
     $this->SetParameterType('alt',CLEAN_STRING);
-    $this->CreateParameter('alt','',$this->Lang('param_alt'));
-
     $this->SetParameterType('name',CLEAN_STRING);
-    $this->CreateParameter('name','',$this->Lang('param_name'));
-
     $this->SetParameterType('height',CLEAN_INT);
-    $this->CreateParameter('height','',$this->Lang('param_height'));
-
     $this->SetParameterType('width',CLEAN_INT);
-    $this->CreateParameter('width','',$this->Lang('param_width'));
-
     $this->SetParameterType('quality',CLEAN_INT);
-    $this->CreateParameter('quality','75',$this->Lang('param_quality'));
-
     $this->SetParameterType('rel',CLEAN_STRING);
-    $this->CreateParameter('rel','75',$this->Lang('param_rel'));
-
-    $this->CreateParameter('max_width','',$this->Lang('param_max_width'));
-    $this->CreateParameter('max_height','',$this->Lang('param_max_height'));
-
     $this->SetParameterType(CLEAN_REGEXP.'/src\d*/',CLEAN_STRING);
     $this->SetParameterType(CLEAN_REGEXP.'/alias\d*/',CLEAN_STRING);
     $this->SetParameterType(CLEAN_REGEXP.'/filter_\w*/',CLEAN_STRING);
+
+    // more smarty plugins
+    $smarty = cmsms()->GetSmarty();
+    $smarty->register_block('cgsi_convert',array('cgsi_utils','cgsi_convert'));
+  }
+
+  function InitializeAdmin()
+  {
+    $this->CreateParameter('alias','',$this->Lang('param_alias'));
+    $this->CreateParameter('noautoscale','',$this->Lang('param_noautoscale'));
+    $this->CreateParameter('nobcache','',$this->Lang('param_nobcache'));
+    $this->CreateParameter('noembed','',$this->Lang('param_noembed'));
+    $this->CreateParameter('noembed','',$this->Lang('param_noembed'));
+    $this->CreateParameter('noauto','',$this->Lang('param_noauto'));
+    $this->CreateParameter('norotate','',$this->Lang('param_norotate'));
+    $this->CreateParameter('notag','',$this->Lang('param_notag'));
+    $this->CreateParameter('noremote','',$this->Lang('param_noremote'));
+    $this->CreateParameter('src','',$this->Lang('param_src'),false);
+    $this->CreateParameter('overwrite','',$this->Lang('param_overwrite'));
+    $this->CreateParameter('id','',$this->Lang('param_id'));
+    $this->CreateParameter('class','',$this->Lang('param_class'));
+    $this->CreateParameter('style','',$this->Lang('param_style'));
+    $this->CreateParameter('title','',$this->Lang('param_title'));
+    $this->CreateParameter('alt','',$this->Lang('param_alt'));
+    $this->CreateParameter('name','',$this->Lang('param_name'));
+    $this->CreateParameter('height','',$this->Lang('param_height'));
+    $this->CreateParameter('width','',$this->Lang('param_width'));
+    $this->CreateParameter('quality','75',$this->Lang('param_quality'));
+    $this->CreateParameter('rel','75',$this->Lang('param_rel'));
+    $this->CreateParameter('max_width','',$this->Lang('param_max_width'));
+    $this->CreateParameter('max_height','',$this->Lang('param_max_height'));
     $this->CreateParameter('filter_blur','',$this->Lang('param_filter_blur'));
     $this->CreateParameter('filter_brightness','',$this->Lang('param_filter_brightness'));
     $this->CreateParameter('filter_colorize','',$this->Lang('param_filter_colorize'));
@@ -141,14 +123,10 @@ class CGSmartImage extends CGExtensions
     $this->CreateParameter('filter_rotate','',$this->Lang('param_filter_rotate'));
     $this->CreateParameter('filter_roundedcorners','',$this->Lang('param_filter_roundedcorners'));
     $this->CreateParameter('filter_watermark','',$this->Lang('param_filter_watermark'));
-
-    $this->RegisterModulePlugin();
-
-    // more smarty plugins
-    $smarty = cmsms()->GetSmarty();
-    $smarty->register_block('cgsi_convert',array('cgsi_utils','cgsi_convert'));
   }
 
+  function LazyLoadAdmin() { return TRUE; }
+  function LazyLoadFrontend() { return TRUE; }
 
   /*---------------------------------------------------------
    GetName()
@@ -173,7 +151,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.6.1';
+    return '1.7.1';
   }
 
   
@@ -182,7 +160,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return '1.9.2';
+    return '1.10.3';
   }
 
 
@@ -429,7 +407,8 @@ class CGSmartImage extends CGExtensions
   {
     $config = cmsms()->GetConfig();
     $prefix = trim($this->GetPreference('image_url_prefix'));
-    if( !$prefix ) $prefix = $config['uploads_url'];
+    if( !$prefix || !startswith($prefix,$config['root_url']) )
+      $prefix = $config['uploads_url'];
     $hascachedir = $this->GetPreference('image_url_hascachedir');
 
     $url = $prefix;
