@@ -212,7 +212,6 @@ class cgsi_utils
     $outp['src'] = '';
     $outp['width'] = '';
     $outp['height'] = '';
-    $outp['alt'] = '';
     $outp['error'] = '';
     $opp = array();  // operation params
     $opp['overwrite'] = 0;
@@ -221,6 +220,7 @@ class cgsi_utils
     $opp['noembed'] = 0;
     $opp['noauto'] = 0;
     $opp['norotate'] = 0;
+    $opp['notimecheck'] = 0;
     $opp['noautoscale'] = 0;
     $opp['notag'] = 0;
     $opp['src'] = '';
@@ -324,6 +324,7 @@ class cgsi_utils
 	  case 'nobcache':
 	  case 'noembed':
 	  case 'norotate':
+          case 'notimecheck':
 	    $opp[$key] = cge_utils::to_bool($value);
 	    break;
 	  }
@@ -364,18 +365,21 @@ class cgsi_utils
 	if( file_exists($tmp) ) $srcfile = $tmp;
       }
     if( !$outp['error'] && !$srcfile && $opp['noremote'] == 0 && 
-	(startswith($opp['src'],'http:') || startswith($opp['src'],'https:') || startswith($opp['src'],'ftp:')) )
+	(startswith($opp['src'],'http:') || startswith($opp['src'],'https:') || startswith($opp['src'],'ftp:')))
        {
 	 // okay, gotta assume that ths is a remote file
 	 // get it, and cache it.
-	 $cachefile = TMP_CACHE_LOCATION.'/cgsi_'.md5($opp['src']).'.img';
-	 if( !file_exists($cachefile) )
+	 if( file_exists($opp['src']) )
 	   {
-	     $data = file_get_contents($opp['src']);
-	     if( !$data ) $opp['error'] = $mod->Lang('error_remotefile',$opp['src']);
-	     if( $data ) file_put_contents($cachefile,$data);
+	     $cachefile = TMP_CACHE_LOCATION.'/cgsi_'.md5($opp['src']).'.img';
+	     if( !file_exists($cachefile) )
+	       {
+		 $data = file_get_contents($opp['src']);
+		 if( !$data ) $opp['error'] = $mod->Lang('error_remotefile',$opp['src']);
+		 if( $data ) file_put_contents($cachefile,$data);
+	       }
+	     $srcfile = $cachefile;
 	   }
-	 $srcfile = $cachefile;
        }
     if( !$outp['error'] && !$srcfile )
       {
@@ -514,7 +518,10 @@ class cgsi_utils
 	$destname = substr($tmp,0,strlen($tmp)-strlen($ext)).'-'.$t2;
     
 	$destdir = $config['uploads_path'].'/_'.$mod->GetName();
-	if( !is_dir($destdir) ) @mkdir($destdir);
+	if( !is_dir($destdir) ) { 
+	  @mkdir($destdir);
+	  touch($destdir.'/index.html');
+	}
 	if( !is_dir($destdir) )
 	  {
 	    $outp['error'] = $mod->Lang('error_mkdir',$destdir);
@@ -525,7 +532,9 @@ class cgsi_utils
 	    $dest_fname = $destdir.'/'.$destname.$ext;
 
 	    $dest_url = $mod->get_cached_image_url($destname).$ext;
-	    if( !file_exists($dest_fname) || $opp['overwrite']  )
+	    $t1 = filemtime($srcfile);
+	    $t2 = file_exists($dest_fname) ? filemtime($dest_fname) : 0;
+	    if( !file_exists($dest_fname) || (($t2 < $t1) && !$opp['notimecheck']) || $opp['overwrite']  )
 	      {
 		$do_transform = 1;
 	      }
@@ -583,7 +592,7 @@ class cgsi_utils
 	$dest_url .= '?x='.time();      
       }
 
-    if( !$outp['alt'] )
+    if( !isset($outp['alt']) )
       {
 	if( $dest_fname ) 
 	  $outp['alt'] = basename($dest_fname);
@@ -773,4 +782,4 @@ class cgsi_utils
 #
 # EOF
 #
-?>
\ No newline at end of file
+?>
